@@ -1,7 +1,7 @@
 /*
     historyplugin.cpp
 
-    Copyright (c) 2003-2004 by Olivier Goffart        <ogoffart@tiscalinet.be>
+    Copyright (c) 2003-2004 by Olivier Goffart        <ogoffart @ kde.org>
               (c) 2003 by Stefan Gehn                 <metz AT gehn.net>
     Kopete    (c) 2003-2004 by the Kopete developers  <kopete-devel@kde.org>
 
@@ -23,7 +23,7 @@
 #include <kplugininfo.h>
 #include <kdeversion.h>
 
-#include "kopetemessagemanagerfactory.h"
+#include "kopetechatsessionmanager.h"
 #include "kopetemetacontact.h"
 #include "kopeteview.h"
 #include "kopetecontactlist.h"
@@ -38,12 +38,8 @@
 #include "historyconfig.h"
 
 typedef KGenericFactory<HistoryPlugin> HistoryPluginFactory;
-#if KDE_IS_VERSION(3,2,90)
 static const KAboutData aboutdata("kopete_history", I18N_NOOP("History") , "1.0" );
 K_EXPORT_COMPONENT_FACTORY( kopete_history, HistoryPluginFactory( &aboutdata )  )
-#else
-K_EXPORT_COMPONENT_FACTORY( kopete_history, HistoryPluginFactory("kopete_history")  )
-#endif
 
 HistoryPlugin::HistoryPlugin( QObject *parent, const char *name, const QStringList & /* args */ )
 : Kopete::Plugin( HistoryPluginFactory::instance(), parent, name ), m_loggerFactory( this )
@@ -69,7 +65,7 @@ HistoryPlugin::HistoryPlugin( QObject *parent, const char *name, const QStringLi
 			KMessageBox::questionYesNo(Kopete::UI::Global::mainWidget(),
 				i18n( "Old history files from Kopete 0.6.x or older has been detected.\n"
 				"Do you want to import and convert it to the new history format?" ),
-				i18n( "History Plugin" ) ) == KMessageBox::Yes )
+				i18n( "History Plugin" ), i18n("Import && Convert"), i18n("Do Not Import") ) == KMessageBox::Yes )
 		{
 			convertOldHistory();
 		}
@@ -133,7 +129,7 @@ void HistoryPlugin::slotViewHistory()
 
 		// TODO: Keep track of open dialogs and raise instead of
 		// opening a new (duplicated) one
-		new HistoryDialog(m, lines);
+		new HistoryDialog(m);
 	}
 }
 
